@@ -43,22 +43,11 @@ def encode_command(message: str):
     print(decoded_temp)
 
 
-def send_command(pumpAddress: str, message: str):
-    commandHeader = '/' + pumpAddress
-    commandFooter = '\r\n'
-    command = commandHeader + message + commandFooter
-    encoded_command = str.encode(command)
-    ser.write(encoded_command)
-    respondbytes2 = ser.readline()  # Read from Serial Port
-    print(respondbytes2)
-    decoded_temp2 = respondbytes2.decode()
-    print('Response :')
-    print(decoded_temp2)
-    '''
+def waitForResponse(header: str, footer: str):
     while True:
         print("inside while")
         time.sleep(0.2)
-        temp = commandHeader + "QR" + commandFooter
+        temp = header + "QR" + footer
         encoded_temp = str.encode(temp)
         ser.write(encoded_temp)
         respond_bytes = ser.readline()
@@ -73,7 +62,21 @@ def send_command(pumpAddress: str, message: str):
         if new_character == '`':
             print("break")
             break
-    '''
+
+
+def send_command(pumpAddress: str, message: str, waitForPump: False):
+    commandHeader = '/' + pumpAddress
+    commandFooter = '\r\n'
+    command = commandHeader + message + commandFooter
+    encoded_command = str.encode(command)
+    ser.write(encoded_command)
+    respondbytes2 = ser.readline()  # Read from Serial Port
+    print(respondbytes2)
+    decoded_temp2 = respondbytes2.decode()
+    print('Response :')
+    print(decoded_temp2)
+    if waitForPump:
+        waitForResponse(commandHeader, commandFooter)
 
 
 
